@@ -62,3 +62,37 @@ my $out;
 IPC::Run::run( $command,
 	       '>',  \$out );
 exit($?);
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+awspollymp3.pl - script converting textfile named $1
+
+=head1 VERSION
+
+version 20240619.1055
+
+=head1 AUTHOR
+
+Walter Daems <wdaems@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2024 by Walter Daems.
+
+This is free software, licensed under:
+
+  The GNU General Public License, Version 3, June 2007
+
+=head1 CONTRIBUTOR
+
+=for stopwords Paul Levrie
+
+Paul Levrie
+
+=cut
